%==========================================================================
%
%   ECE 5340/6340 homework 5.
%
%   Solve for the capacitor plate potentials using SOR.
%
%       E-field produced by two parallel capacitor plates.  The top plate
%   is at a uniform potential of +1.0 V while the bottom plate is at a
%   uniform potential of -1.0 V.  
%
%==========================================================================
%
%   James Nagel
%   Department of Electrical and Computer Engineering
%   University of Utah, Salt Lake City, Utah
%   nageljr@ieee.org
%   Copyright February 8, 2012

close all;
clear all;

%==========================================================================
%  Simulation parameters.
%==========================================================================

%  Physical constants.
e_0 = 8.854e-12;    %  Permittivity of free-space.
c_0 = 3e8;          %  Speed of light in a vacuum.

%  Voltage of top strip.
Vtop = 1;

%  Define model parameters.
W  = [0.5:0.1:1.5]*1e-2;    %  Strip width (m).
d  = 1e-3;
er = 3;

Nw = length(W);

%  
Z0_calc = zeros(Nw,1);
Z0_sim  = zeros(Nw,1);

for n = 1:Nw
    
        %  Calculate analyical value.
    Z0_calc(n) = Microstrip_Impedance(W(n),d,er);
    
    %  Simulate dielectric system.
    [V,h,EPS] = Solve_Microstrip(W(n),d,er);
    [Ex,Ey,Emag] = staggered_2D_gradient(V,h);
    
    %  Simulate free-space system.
    [V0,h] = Solve_Microstrip(W(n),d,1);
    [Ex0,Ey0] = staggered_2D_gradient(V0,h);
    
    %  Solve for indices of the Gaussian contour vertices.
    [Ny,Nx] = size(V);
    x1 = round(W(n)/2/h);
    x2 = Nx - x1;
    y1 = round(d/2/h);
    y2 = round(d/h) + y1;
    
    
    %  Gaussian contour for dielectric simulation.
    qL = trapz(EPS(y1:y2,x1).*Ex(y1:y2,x1));
    qR = trapz(EPS(y1:y2,x2).*Ex(y1:y2,x2));
    qT = trapz(EPS(y2,x1:x2).*Ey(y2,x1:x2));
    qB = trapz(EPS(y1,x1:x2).*Ey(y1,x1:x2));
    
    q = e_0*h*(-qL + qR + qB - qT);
    C = q/Vtop;
    
    %  Gaussian contour for free-space simulation.
    qL = trapz(Ex0(y1:y2,x1));
    qR = trapz(Ex0(y1:y2,x2));
    qT = trapz(Ey0(y2,x1:x2));
    qB = trapz(Ey0(y1,x1:x2));
    
    q0 = e_0*h*(-qL + qR + qB - qT);
    C0 = q0/Vtop;
    
    %  Characteristic Impedance.
    Z0_sim(n) = (1/c_0)*1/sqrt(C*C0);
    

end

figure(1)
clf
plot(W*1e2,Z0_sim,'--r','linewidth',2);
hold on
plot(W*1e2,Z0_calc,'-k','linewidth',2);
X = xlabel('Microstrip Width (cm)');
Y = ylabel('Impedance (\Omega)');
set(X,'fontname','verdana','fontsize',24);
set(Y,'fontname','verdana','fontsize',24);
set(gca,'fontsize',18);
legend('Simulated','Analytical');
axis([min(W)*1e2 max(W)*1e2 0 35]);



